import BN from 'bn.js';
import { TxDb } from '@polkadot/db/types';
import { TrieDb } from '@polkadot/trie-db/types';
export declare type DbPathPrefix = 'database';
export declare type DbConfig$Type = 'file' | 'lmdb' | 'memory';
export declare type DbConfig = {
    compact: boolean;
    path: string;
    snapshot: boolean;
    type: DbConfig$Type;
};
export declare type StorageMethod<P, R> = {
    del: (...params: Array<any>) => void;
    get: (...params: Array<any>) => R;
    set: (value: P, ...params: Array<any>) => void;
    onUpdate: (callback: (value: P) => void) => void;
};
export declare type StorageMethod$Account = StorageMethod<Uint8Array, Uint8Array>;
export declare type StorageMethod$Bn = StorageMethod<BN | number, BN>;
export declare type StorageMethod$Bool = StorageMethod<boolean, boolean>;
export declare type StorageMethod$U8a = StorageMethod<Uint8Array, Uint8Array>;
export declare type StorageMethod$ArrayAccount = StorageMethod<Array<Uint8Array>, Array<Uint8Array>>;
export declare type StorageMethod$ArrayU8a = StorageMethod<Array<Uint8Array>, Array<Uint8Array>>;
export declare type StorageMethods = StorageMethod$Account | StorageMethod$Bn | StorageMethod$Bool | StorageMethod$U8a | StorageMethod$ArrayU8a | StorageMethod$ArrayAccount;
export declare type BlockDb = {
    db: TxDb;
    bestHash: StorageMethod$U8a;
    bestNumber: StorageMethod$Bn;
    blockData: StorageMethod$U8a;
    hash: StorageMethod$U8a;
    header: StorageMethod$U8a;
};
export declare type StateDb = {
    db: TrieDb;
    code: StorageMethod$U8a;
};
export interface ChainDbs {
    readonly blocks: BlockDb;
    readonly state: StateDb;
    snapshot(): void;
}
